package com.javacorporate.xml.servlet;

/*
 * Export.java
 *
 * Copyright 1999 Javacorporate Ltd.
 */

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;
import java.util.*;
import com.javacorporate.db.DBException;
import com.javacorporate.dbobj.SecuredDBObject;
import java.util.Hashtable;
import com.javacorporate.common.dbobj.Setup;
import com.javacorporate.common.dbobj.User;
import com.javacorporate.common.dbobj.LogEntry;
import com.javacorporate.common.util.LogHandler;
import com.javacorporate.common.util.StringUtil;
import com.javacorporate.common.html.*;
import com.javacorporate.common.servlet.DBServlet;
import java.net.URLEncoder;
import com.javacorporate.xml.dbobj.XMLDBObject;

/**
 * Export the specified DBObject's data in a simple XML format
 *
 * @version		$Revision: 1.3 $  $Date: 2000/04/22 14:22:26 $
 * @author		Michael Nash
 */
public class Export extends DBServlet {
	private String thisClass = new String(getClass().getName() + ".");
	private String thisCommand = null;

	private String closeFont(String messageColor) {
		if (messageColor.equals("")) {
			return new String("");
		} 
		return new String("</font>");
	}
 	/**
 	 * Display the contents of the current server log to the user
 	 *
 	 * @param	request Standard request object
 	 * @param	response Standard reponse object
 	 * @throws	ServletException If an uncaught exception occurs
 	 * @throws	IOException If an I/O error occurs communicating with the client
	 */
	public void doGet (HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

		String myName = new String(thisClass + "doGet(HttpServletRequest, HttpServletResponse)");

		PrintWriter	out = response.getWriter();

   		try	{
			super.doGet(request, response);

			String userName = null;
			HttpSession session = request.getSession(true);
			String sessionUserName = StringUtil.notNull((String) session.getValue("UserName"));
			
			if ((!sessionUserName.equals("")) && (!sessionUserName.equals("NONE"))) {
				userName = sessionUserName;
			} else {
				userName = StringUtil.notNull(request.getParameter("UserName"));
				if (userName.equals("")) {
					throw new ServletException(myName + ":Must specify UserName parameter");
				}
	      		String password = StringUtil.notNull(request.getParameter("Password"));
	      		if (password.equals("")) {
		      		throw new ServletException(myName + ":Must specify a Password parameter");
	      		}

	      		User myUser = new User();
	      		myUser.setField("UserName", userName);
	      		myUser.retrieve();
	      		if (!myUser.getField("Password").equals(password)) {
		      		throw new ServletException(myName + ":Invalid login when attempting to export");
	      		}
	      		session.putValue("UserName", userName);
			}
			
			checkAppSecurity(userName, getClass().getName(), getTitle());

			response.setContentType("text/html");
	   		//response.setContentType("text/xml");

	   		out.println("<?xml version=\"1.0\" standalone=\"no\"?>");
	   		out.println("<!DOCTYPE ExpressoData [");
	   		out.println("<!ELEMENT DBObjects (DBObject+)>");
	   		out.println("<!ELEMENT DBObject (ObjectName, TableName, Data)>");
	   		out.println("<!ELEMENT ObjectName (#PCDATA)>");
	   		out.println("<!ELEMENT TableName (#PCDATA)>");
	   		out.println("<!ELEMENT Data (DataRecord+)>");
	   		out.println("<!ELEMENT DataRecord (Field)>");
	   		out.println("<!ELEMENT Field (FieldName, FieldValue)>");
	   		out.println("<!ELEMENT FieldName (#PCDATA)>");
	   		out.println("<!ELEMENT FieldValue (#PCDATA)>");
	   		out.println("]>");
	   		out.println("<DBObjects>");
			
			String objName = StringUtil.notNull(request.getParameter("dbobj"));
			SecuredDBObject thisObject = getDBObj(objName);

			XMLDBObject myXML = new XMLDBObject(thisObject);
			myXML.exportToStreamXML(out);

			//String myURL = new String("http://localhost/servlet/Export?dbobj=User&UserName=Admin&Password=shamu4547");
			//myXML.importFromURL(myURL);

			out.println("</DBObjects>");
			out.close();
   		} catch(SecurityException se) {
		   	showErrorWithLogin(se, out, request, response);
   		} catch(Exception ioe) {
			showError(ioe, out);
		}
	} /* doGet(HttpServletRequest, HttpServletResponse) */
/**
	 * Given a class name that contains a SecuredDBObject, instantiate an
	 * instance of the object & return it. Also associates the current user
	 * name (from the session) with the object so
	 * that requests to maniupluate the object can be passed through
	 * appropriate security
	 *
	 * @param	
	 * @returns	A SecuredDBObject from the class of the given name
	 * @throws	DBException if the object cannot be created or set up
	 */
	protected synchronized SecuredDBObject getDBObj(String myDBObjName) throws DBException, ServletException {

		String myName = new String(thisClass + "getDBObj(String)");

		SecuredDBObject returnObj = null;

		
		if (myDBObjName == null) {
			throw new DBException(myName + ":Database object name is null");
		}
		if (myDBObjName.equals("")) {
			throw new DBException(myName + ":Database object name is empty "
				+ "string");
		}
		if (myDBObjName.equals("NONE")) {
			throw new DBException(myName + ":Database object name is NONE");
		}

		try	{
			returnObj = (SecuredDBObject) Class.forName(myDBObjName).newInstance();

			if (returnObj == null) {
				throw new DBException(myName + ":Null object - "
					+ "instantiate failed for database object " + myDBObjName);
			}
		} catch(IllegalAccessException ie) {
			throw new DBException(myName + ":Illegal Access exception starting "
				+ "SecuredDBObject class  " + myDBObjName + ":" 
				+ ie.getMessage());
		} catch(InstantiationException ie) {
			throw new DBException(myName + ":Can't instantiate SecuredDBObject "
				+ "class " + myDBObjName + ":" + ie.getMessage());
		} catch(ClassNotFoundException se) {
			throw new DBException(myName + ":Can't find a SecuredDBObject "
				+ "class called " + myDBObjName + ":" + se.getMessage());
		} catch(NoClassDefFoundError fe) {
			throw new DBException(myName + ":Can't find class definition for " 
				+ myDBObjName + ":" + fe.getMessage());
		} catch(Exception eo)	{
			throw new DBException(myName + ":Exception loading SecuredDBObject:"
				+ eo.getMessage());
		}

		returnObj.setUser("SYSTEM");


		return returnObj;
	} /* getDBObj(String) */
	public String getTitle() {
		return new String("Export Data");
	}
} /* Export */
