package com.javacorporate.xml.trx;

import java.util.Enumeration;
import java.util.Vector;
import java.util.Hashtable;
import com.javacorporate.common.html.*;
import com.javacorporate.common.dbobj.UserGroup;
import com.javacorporate.common.dbobj.SchemaList;
import com.javacorporate.dbobj.ValidValue;
import com.javacorporate.common.dbobj.DBObjSecurity;
import com.javacorporate.db.DBException;
import com.javacorporate.db.DBConnectionPool;
import com.javacorporate.db.DBConnection;
import com.javacorporate.dbobj.Schema;
import com.javacorporate.dbobj.DBObject;
import com.javacorporate.common.util.LogHandler;
import com.javacorporate.common.util.StringUtil;
import java.util.StringTokenizer;
import com.javacorporate.common.trx.DBTransaction;
import com.javacorporate.common.trx.TrxException;
import com.javacorporate.common.trx.State;
import com.javacorporate.common.trx.Action;
import com.javacorporate.common.trx.Input;
import com.javacorporate.common.trx.Output;
import com.javacorporate.xml.dbobj.XMLDBObject;
import java.io.*;

/**
 * The XML transaction allows authorized users to easily
 * import and export DBObject contents to XML formats
 */
public class XMLTrx extends DBTransaction {

	private String thisClass = getClass().getName() + ".";


	/**
	 * Object to enclose the existing security info for a database object
	 */
	private class CurrentSecurity {
		public boolean addAllowed = false;
		public boolean updateAllowed = false;
		public boolean searchAllowed = false;
		public boolean deleteAllowed = false;
		public String description = new String("none");

		public CurrentSecurity() {
			super();
		}
	} /* currentSecurity */

	/**
	 * Our constructor declares the states this transaction supports
	 */
	public XMLTrx() {

		State promptImport = new State("promptImport", "Prompt for Parameters for Import");
		addState(promptImport);

		State promptFileImport = new State("promptFileImport", "Prompt for Parameters for File Import");
		addState(promptFileImport);

		State promptFileExport = new State("promptFileExport", "Prompt for Parameters for File Export");
		addState(promptFileExport);

		State doFileExport = new State("doFileExport", "Export Data to a File");
		doFileExport.addParameter("FileName");
		doFileExport.addParameter("Schema");
		addState(doFileExport);

		State doFileImport = new State("doFileImport", "Import Data from a File");
		doFileImport.addParameter("FileName");
		addState(doFileImport);

		State doImport = new State("doImport", "Import Data from remote Server");
		doImport.addParameter("DBObjectName");
		doImport.addParameter("Server");
		doImport.addParameter("Login");
		doImport.addParameter("Password");
		addState(doImport);

	} /* constructor */
	private void doFileExportState() throws TrxException {
		String myName = new String(thisClass + "doFileImportState()");

		try {
			FileOutputStream fout = new FileOutputStream(getParameter("FileName") + ".xml", false);
			BufferedOutputStream bout = new BufferedOutputStream(fout);
			PrintStream XMLFileStream = new PrintStream(bout);

			XMLFileStream.println("<?xml version=\"1.0\" standalone=\"no\"?>");
	   		XMLFileStream.println("<!DOCTYPE ExpressoData [");
	   		XMLFileStream.println("<!ELEMENT DBObjects (DBObject+)>");
	   		XMLFileStream.println("<!ELEMENT DBObject (ObjectName, TableName, Data)>");
	   		XMLFileStream.println("<!ELEMENT ObjectName (#PCDATA)>");
	   		XMLFileStream.println("<!ELEMENT TableName (#PCDATA)>");
	   		XMLFileStream.println("<!ELEMENT Data (DataRecord+)>");
	   		XMLFileStream.println("<!ELEMENT DataRecord (Field)>");
	   		XMLFileStream.println("<!ELEMENT Field (FieldName, FieldValue)>");
	   		XMLFileStream.println("<!ELEMENT FieldName (#PCDATA)>");
	   		XMLFileStream.println("<!ELEMENT FieldValue (#PCDATA)>");
	   		XMLFileStream.println("]>");
	   		XMLFileStream.println("<DBObjects>");

	   		XMLFileStream.flush();
			XMLFileStream.close();

			Schema mySchema = getSchema(getParameter("Schema"));
			for (Enumeration e = mySchema.getMembers(); e.hasMoreElements(); ) {
				XMLDBObject myXMLObj = new XMLDBObject((DBObject) e.nextElement());
				myXMLObj.exportToFile(getParameter("FileName"));
			}

			FileOutputStream fout2 = new FileOutputStream(getParameter("FileName") + ".xml", true);
			BufferedOutputStream bout2 = new BufferedOutputStream(fout2);
			PrintStream XMLFileStream2 = new PrintStream(bout2);

			XMLFileStream2.println("</DBObjects>");
			XMLFileStream2.flush();
			XMLFileStream2.close();
			
		} catch (Exception de) {
			throw new TrxException(de.getMessage());
		}
	} /* doFileExportState() */
	private void doFileImportState() throws TrxException {
		String myName = new String(thisClass + "doFileImportState()");

		try {
			XMLDBObject myXMLObj = new XMLDBObject();
			myXMLObj.importFromFile(getParameter("FileName"));

			Exception ex = null;
			for (Enumeration e = myXMLObj.getErrorList().elements(); e.hasMoreElements(); ) {
				ex = (Exception) e.nextElement();
				addOutput(new Output(ex.getMessage()));
			}
		} catch (DBException de) {
			throw new TrxException(de.getMessage());
		}
	} /* doFileImportState() */
	private void doImportState() throws TrxException {
		String myName = new String(thisClass + "doImportState()");

		String importURL = new String("http://" + getParameter("Server") + "/servlet/Export?dbobj=" + getParameter("DBObjectName")
			+ "&UserName=" + getParameter("Login") + "&Password=" + getParameter("Password"));

		try {
			XMLDBObject myXMLObj = new XMLDBObject();
			myXMLObj.importFromURL(importURL);
		} catch (DBException de) {
			throw new TrxException(de.getMessage());
		}
	} /* doImportState() */
	/**
	 * Instantiate & return the schema class given in the current parameter
	 *
	 * @returns A Schema object instantiated from the class named by the 
	 *	'SchemaClass' parameter
	 */
	private Schema getSchema() throws TrxException {
		String myName = new String(thisClass + "getSchema()");

		Schema mySchema;
		String className = getParameter("SchemaClass");
		if (className == null) {
			throw new TrxException(myName + ":No parameter 'SchemaClass',"
				+ " can't read current schema");
		}

		DBConnectionPool myPool = null;
		DBConnection myConnection = null;

		try	{
			myPool = DBConnectionPool.getInstance();
			myConnection = myPool.getConnection(myName);
			mySchema = (Schema) 
				Class.forName(getParameter("SchemaClass")).newInstance();
		} catch(IllegalAccessException ie) {
			throw new TrxException(myName + ":Illegal Access "
				+ "Exception loading Schema class  " 
				+ getParameter("SchemaClass") + ":" + ie.getMessage());
		} catch(InstantiationException ie) {
			throw new TrxException(myName + ":Can't instantiate "
				+ "Schema class " + getParameter("SchemaClass")
				+ ":" + ie.getMessage());
		} catch(ClassNotFoundException se) {
			throw new TrxException(myName + ":Can't find a Schema "
				+ "class called " + getParameter("SchemaClass") + ":" 
				+ se.getMessage());
		} catch(Exception eo)	{
			LogHandler.tryLog(myName, eo);
			throw new TrxException(myName + ":Exception loading "
				+ "Schema " + getParameter("SchemaClass") 
				+ "- see detailed message in server log:"
				+ eo.getMessage());
		} finally {
			if (myPool != null) {
				myPool.release(myConnection);
			}
		}
		return mySchema;
	}  /* getSchema() */
	/**
	 * Instantiate & return the schema class given in the current parameter
	 *
	 * @returns A Schema object instantiated from the class named by the 
	 *	'SchemaClass' parameter
	 */
	private Schema getSchema(String schemaName) throws TrxException {
		String myName = new String(thisClass + "getSchema()");

		Schema mySchema;

		try	{
			mySchema = (Schema) Class.forName(schemaName).newInstance();
		} catch(IllegalAccessException ie) {
			throw new TrxException(myName + ":Illegal Access Exception loading Schema class  " 
				+ schemaName + ":" + ie.getMessage());
		} catch(InstantiationException ie) {
			throw new TrxException(myName + ":Can't instantiate Schema class " + schemaName + ":" + ie.getMessage());
		} catch(ClassNotFoundException se) {
			throw new TrxException(myName + ":Can't find a Schema class called " + schemaName + ":" 
				+ se.getMessage());
		} catch(Exception eo)	{
			LogHandler.tryLog(myName, eo);
			throw new TrxException(myName + ":Exception loading Schema " + schemaName 
				+ "- see detailed message in server log:" + eo.getMessage());
		} 
		return mySchema;
	}  /* getSchema() */
	/**
	 * Return the title of this Transaction 
	 */
	public String getTitle() {
		return new String("Database Object XML Import/Export");
	} /* getTitle() */
	public void newState(String newState) throws TrxException {
		String myName = new String(thisClass + "newState(String)");
		
		super.newState(newState);

		if (newState.equals("promptImport")) {
			promptImportState();
		} else if (newState.equals("doImport")) {
			doImportState();
		} else if (newState.equals("doFileExport")) {
			doFileExportState();
		} else if (newState.equals("doFileImport")) {
			doFileImportState();
		} else {
			throw new TrxException(myName + ":No such state '" + newState + "' for transaction " + thisClass);
		}

		if (!newState.equals("promptImport")) {
			Action again = new Action("Start Again", getClass().getName());
			again.setName("again");
			again.addParam("state", "promptImport");
			addAction(again);
		}

		
	} /* newState(String) */
	private void promptFileExportState() throws TrxException {
		String myName = new String(thisClass + "promptFileExportState()");

		Input fileName = new Input("FileName");
		fileName.setLabel("XML File Name (no extension)");
		addInput(fileName);

		Input schemaName = new Input("Schema");
		schemaName.setLabel("Schema Object Name");
		addInput(schemaName);
		
	} /* promptState() */
	private void promptFileImportState() throws TrxException {
		String myName = new String(thisClass + "promptFileImportState()");

		Input fileName = new Input("FileName");
		fileName.setLabel("XML File Name");
		addInput(fileName);
		
	} /* promptState() */
	private void promptImportState() throws TrxException {
		String myName = new String(thisClass + "promptState()");

		Input server = new Input("Server");
		server.setLabel("Server Name");
		addInput(server);

		Input dbobjName = new Input("DBObjectName");
		dbobjName.setLabel("Database Object:");
		addInput(dbobjName);

		Input login = new Input("Login");
		dbobjName.setLabel("Login:");
		addInput(dbobjName);

		Input password = new Input("Password");
		password.setLabel("Password:");
		addInput(password);
		
	} /* promptState() */
	private void promptState() throws TrxException {
		String myName = new String(thisClass + "promptState()");

		/* First the inputs */
		Input chooseGroup = new Input();
		chooseGroup.setLabel("Choose Group");
		chooseGroup.setName("GroupName");
		Vector vg = new Vector(2);
		DBConnectionPool myPool = null;
		DBConnection myConnection = null;
	
		try {
			myPool = DBConnectionPool.getInstance();
			myConnection = myPool.getConnection(myName);

			UserGroup gl = new UserGroup("SYSTEM");
			UserGroup oneGroup = null;
			for (Enumeration e = 
				gl.searchAndRetrieve("Descrip").elements(); 
				e.hasMoreElements(); ) {

				oneGroup = (UserGroup) e.nextElement();
				vg.addElement(new ValidValue(oneGroup.getField("GroupName"), 
					oneGroup.getField("Descrip")));
			}
			if (vg.size() == 0) {
				throw new TrxException(myName + ":There are no groups "
					+ "defined.");
			}
			chooseGroup.setValidValues(vg);
			addInput(chooseGroup);

			/* ..and a schema */
			Input chooseSchema = new Input();
			chooseSchema.setLabel("Choose Schema");
			chooseSchema.setName("SchemaClass");
			Vector v2 = new Vector(2);
			v2.addElement(new ValidValue("com.javacorporate.common."
				+ "JavaCorpSchema", "General"));
		
			SchemaList sl = new SchemaList("SYSTEM");
			SchemaList oneSchema = null;
			for (Enumeration e = sl.searchAndRetrieve("Descrip").elements(); 
				e.hasMoreElements(); ) {

				oneSchema = (SchemaList) e.nextElement();
				v2.addElement(new ValidValue(oneSchema.getField("SchemaClass"), 
					oneSchema.getField("Descrip")));
			}
			chooseSchema.setValidValues(v2);
			addInput(chooseSchema);

			/* now the actions */
			Action doDBObj = new Action("Set Security", getClass().getName());
			doDBObj.setName("adminDBobj");
			doDBObj.addParam("state", "dbobjmatrix");
			addAction(doDBObj);
		} catch (DBException de) {
			throw new TrxException(de.getMessage());
		} finally {
			if (myPool != null) {
				myPool.release(myConnection);
			}
		}
	} /* promptState() */
	/**
	 * Return a hash of existing security info
	 */
	private Hashtable readSecurity() throws TrxException {
		String myName = new String(thisClass + "readSecurity()");

		Hashtable h = new Hashtable(4);

		DBConnectionPool myPool = null;
		DBConnection myConnection = null;

		try {
			myPool = DBConnectionPool.getInstance();
			myConnection = myPool.getConnection(myName);

			DBObject oneDBObj = null;
				
			DBObjSecurity secur = new DBObjSecurity("SYSTEM");
			CurrentSecurity oneSec;
			
			for (Enumeration e = getSchema().getMembers();
				e.hasMoreElements(); ) {
			
				oneSec = new CurrentSecurity();
					
				oneDBObj = (DBObject) e.nextElement();
				secur.clear();
				secur.setField("DBObjectName", oneDBObj.getClass().getName());
				secur.setField("GroupName", getParameter("GroupName"));

				oneSec.description = oneDBObj.getDescription();
				secur.setField("MethodCode", "A");
				if (secur.find()) {
					oneSec.addAllowed = true;
				}
				secur.setField("MethodCode", "S");
				if (secur.find()) {
					oneSec.searchAllowed = true;
				}
				secur.setField("MethodCode", "U");
				if (secur.find()) {
					oneSec.updateAllowed = true;
				}
				secur.setField("MethodCode", "D");
				if (secur.find()) {
					oneSec.deleteAllowed = true;
				}
				h.put(secur.getField("DBObjectName"), oneSec);
			}
			return h;
		} catch (DBException de) {
			throw new TrxException(de.getMessage());
		} finally {
			if (myPool != null) {
				myPool.release(myConnection);
			}
		}
	}  /* readSecurity */
} /* DBSecurityMatrix */
