package org.w3c.dom.html;

/*
 * Copyright (c) 2000 World Wide Web Consortium,
 * (Massachusetts Institute of Technology, Institut National de
 * Recherche en Informatique et en Automatique, Keio University). All
 * Rights Reserved. This program is distributed under the W3C's Software
 * Intellectual Property License. This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE. See W3C License http://www.w3.org/Consortium/Legal/ for more
 * details.
 */

/**
 *  A selectable choice. See the  OPTION element definition in HTML 4.0.
 */
public interface HTMLOptionElement extends HTMLElement {
	/**
	 *  Represents the value of the HTML selected attribute. The value of this 
	 * attribute does not change if the state of the corresponding form 
	 * control, in an interactive user agent, changes. Changing 
	 * <code>defaultSelected</code> , however, resets the state of the form 
	 * control. See the  selected attribute definition in HTML 4.0.
	 */
	public boolean getDefaultSelected();
	/**
	 *  The control is unavailable in this context. See the  disabled 
	 * attribute definition in HTML 4.0.
	 */
	public boolean getDisabled();
	/**
	 *  Returns the <code>FORM</code> element containing this control. Returns 
	 * <code>null</code> if this control is not within the context of a form. 
	 */
	public HTMLFormElement getForm();
	/**
	 *  The index of this <code>OPTION</code> in its parent <code>SELECT</code>
	 *  , starting from 0.
	 */
	public int getIndex();
	/**
	 *  Option label for use in hierarchical menus. See the  label attribute 
	 * definition in HTML 4.0.
	 */
	public String getLabel();
	/**
	 *  Represents the current state of the corresponding form control, in an 
	 * interactive user agent. Changing this attribute changes the state of 
	 * the form control, but does not change the value of the HTML selected 
	 * attribute of the element.
	 */
	public boolean getSelected();
	/**
	 *  The text contained within the option element. 
	 */
	public String getText();
	/**
	 *  The current form control value. See the  value attribute definition in 
	 * HTML 4.0.
	 */
	public String getValue();
	public void setDefaultSelected(boolean defaultSelected);
	public void setDisabled(boolean disabled);
	public void setLabel(String label);
	public void setSelected(boolean selected);
	public void setValue(String value);
}
