package org.w3c.dom.html;

/*
 * Copyright (c) 2000 World Wide Web Consortium,
 * (Massachusetts Institute of Technology, Institut National de
 * Recherche en Informatique et en Automatique, Keio University). All
 * Rights Reserved. This program is distributed under the W3C's Software
 * Intellectual Property License. This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE. See W3C License http://www.w3.org/Consortium/Legal/ for more
 * details.
 */

import org.w3c.dom.DOMException;

/**
 *  A row in a table. See the  TR element definition in HTML 4.0.
 */
public interface HTMLTableRowElement extends HTMLElement {
	/**
	 *  Delete a cell from the current row.
	 * @param index  The index of the cell to delete, starting from 0.
	 * @exception DOMException
	 *    INDEX_SIZE_ERR: Raised if the specified <code>index</code> is 
	 *   greater than or equal to the number of cells.
	 */
	public void deleteCell(int index)
						   throws DOMException;   
	/**
	 *  Horizontal alignment of data within cells of this row. See the  align 
	 * attribute definition in HTML 4.0.
	 */
	public String getAlign();
	/**
	 *  Background color for rows. See the  bgcolor attribute definition in 
	 * HTML 4.0. This attribute is deprecated in HTML 4.0.
	 */
	public String getBgColor();
	/**
	 *  The collection of cells in this row. 
	 */
	public HTMLCollection getCells();
	/**
	 *  Alignment character for cells in a column. See the  char attribute 
	 * definition in HTML 4.0.
	 */
	public String getCh();
	/**
	 *  Offset of alignment character. See the  charoff attribute definition 
	 * in HTML 4.0.
	 */
	public String getChOff();
	/**
	 *  The index of this row, relative to the entire table, starting from 0. 
	 * This is in document tree order and not display order. The 
	 * <code>rowIndex</code> does not take into account sections (
	 * <code>THEAD</code> , <code>TFOOT</code> , or <code>TBODY</code> ) 
	 * within the table.
	 */
	public int getRowIndex();
	/**
	 *  The index of this row, relative to the current section (
	 * <code>THEAD</code> , <code>TFOOT</code> , or <code>TBODY</code> ), 
	 * starting from 0.
	 */
	public int getSectionRowIndex();
	/**
	 *  Vertical alignment of data within cells of this row. See the  valign 
	 * attribute definition in HTML 4.0.
	 */
	public String getVAlign();
	/**
	 *  Insert an empty <code>TD</code> cell into this row. If 
	 * <code>index</code> is equal to the number of cells, the new cell is 
	 * appended
	 * @param index  The place to insert the cell, starting from 0.
	 * @return  The newly created cell.
	 * @exception DOMException
	 *    INDEX_SIZE_ERR: Raised if the specified <code>index</code> is 
	 *   greater than the number of cells.
	 */
	public HTMLElement insertCell(int index)
								  throws DOMException;  
	public void setAlign(String align);
	public void setBgColor(String bgColor);
	public void setCh(String ch);
	public void setChOff(String chOff);
	public void setVAlign(String vAlign);
}
